@@ -5,12 +5,12 @@ package MarpaX::ESLIF;
 use parent qw/MarpaX::ESLIF::Base/;
 use MarpaX::ESLIF::String;       # Make sure it is loaded, the XS is using it
 use MarpaX::ESLIF::RegexCallout; # Make sure it is loaded, the XS is using it
+use XSLoader ();
 
 # ABSTRACT: ESLIF is Extended ScanLess InterFace
 
 our $AUTHORITY = 'cpan:JDDPAUSE'; # AUTHORITY
 
-use vars qw/$VERSION/;
 use Config;
 
 #
@@ -62,14 +62,25 @@ BEGIN {
 # Bootstrap
 #
 BEGIN {
-    our $VERSION = '6.0.29'; # VERSION
-
-    require XSLoader;
-    # Modules that we depent on bootstrap
+    #
+    our $VERSION = '6.0.33.1'; # VERSION
+    #
+    # Note that $VERSION is always defined when you use a distributed CPAN package.
+    # With old versions of perl, only the XSLoader::load(__PACKAGE__, $version) works.
+    # E.g. with perl-5.10, doing directly:
+    # make test
+    # within the repository may yell like this:
+    # Error:  XSLoader::load('Your::Module', $Your::Module::VERSION)
+    # In this case, you can put the module version in the MARPAX_ESLIF_VERSION
+    # environment variable, e.g.:
+    # MARPAX_ESLIF_VERSION=999.999.999 make test
+    #
+    # Modules that we depend on bootstrap
     use Math::BigFloat qw//;
     use Math::BigInt qw//;
     use Encode qw//;
-    XSLoader::load(__PACKAGE__, $VERSION);
+    my $version = eval q{$VERSION} // $ENV{MARPAX_ESLIF_VERSION}; ## no critic
+    defined($version) ? XSLoader::load(__PACKAGE__, $version) : XSLoader::load();
 }
 
 # Load our explicit sub-modules
@@ -112,7 +123,7 @@ MarpaX::ESLIF - ESLIF is Extended ScanLess InterFace
 
 =head1 VERSION
 
-version 6.0.29
+version 6.0.33.1
 
 =head1 SYNOPSIS
 
@@ -227,26 +238,6 @@ L<MarpaX::ESLIF::Introduction>, L<PCRE2|http://www.pcre.org/>, L<MarpaX::ESLIF::
 
 Jean-Damien Durand <jeandamiendurand@free.fr>
 
-=head1 CONTRIBUTORS
-
-=for stopwords Jean-Damien Durand Jeffrey Kegler
-
-=over 4
-
-=item *
-
-Jean-Damien Durand <Jean-Damien.Durand@newaccess.ch>
-
-=item *
-
-Jeffrey Kegler <jeffreykegler@jeffreykegler.com>
-
-=item *
-
-Jeffrey Kegler <jeffreykegler@protonmail.com>
-
-=back
-
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2017 by Jean-Damien Durand.
